-- Created by: BadLuckBurt
-- Date: 5/3/15
-- Time: 2:26 PM
--

-- ***********************************
-- * Game logic and global variables *
-- ***********************************
system = require "core.system"
keymap = require "config.keymap"	-- Load key configuration
tilemapGenerator = require "modules.tilemapGenerator"
tilemapRenderer = require "modules.tilemapRenderer"
playerTile = require "modules.playerTile"

debug = true

iMapRefresh = 0
dtMax = 1 / 120 -- 0.01666 milliseconds
dtCurrent = 0
dtPixelStep = 0

tmpWaterMap = nil
waterMap = nil
waterMapCanvas = nil

function love.load()
	system:initialize()

	tilemapGenerator.tileWidth = 32
	tilemapGenerator.tileHeight = 32
	tilemapGenerator:setDimensions(system.width, system.height)

	waterMap = tilemapGenerator:generateWater(false)
	waterMap.canvas = tilemapRenderer:drawMap(waterMap)

	playerTile:calcMax(system.width, system.height)
	playerTile:createCanvas(true)
end

function love.update(dt)
	dtCurrent = dtCurrent + dt
	if dtCurrent >= dtMax then
		local dtPixelStep = system:getPixelStep(dtCurrent, dtMax)
		playerTile:calcMovement(dtPixelStep, keymap)
		dtCurrent = 0
	end
	if iMapRefresh == 1 then
		tmpWaterMap = tilemapGenerator:generateWater(false)
	elseif iMapRefresh == 2 then
		tmpWaterMap.canvas = tilemapRenderer:drawMap(tmpWaterMap)
		waterMap = tmpWaterMap
		iMapRefresh = 0
	end
end

function love.draw()
	love.graphics.draw(waterMap.canvas, 0, 0, 0, 1, 1, 0, 0, 0, 0)
	playerTile:render()
	system:printFPS()
end

-- **************
-- * User input *
-- **************
function love.keypressed(key, isrepeat)
	-- Notes: https://www.love2d.org/wiki/love.keypressed
	-- Key repeat needs to be enabled with love.keyboard.setKeyRepeat for repeat keypress events to be received.
	--Exit immediately when Escape is pressed
	if key == 'escape' then love.event.quit() end

	if key == keymap.r then
		iMapRefresh = iMapRefresh + 1
	end

	keymap:press(key)
end

function love.keyreleased(key)
	keymap:release(key)
end

function love.mousefocus(f)

end

function love.mousemoved(x, y, dx, dy)

end

function love.mousepressed(x, y, button)

end

function love.mousereleased(x, y, button)

end

-- *****************
-- * Window events *
-- *****************
function love.focus(f)

end

function love.resize(w, h)

end

-- ******************
-- * Error handling *
-- ******************
function love.errhand(msg)
	print(msg)
end

function love.threaderror(thread, errorstr)

end

-- **************
-- * Quit logic *
-- **************
function love.quit()
	playerTile = nil
end

